@@ -46,16 +46,18 @@ import json
 from math import ceil
 from urllib.request import urlopen
 from urllib.error import URLError
+from .pbar import track_wide
 from rich.logging import RichHandler
 from rich.console import Console
 from rich.progress import (
     BarColumn,
+    SpinnerColumn,
     DownloadColumn,
     TextColumn,
     TransferSpeedColumn,
     TimeRemainingColumn,
     Progress,
-    track,
+#    track,
 )
 from concurrent.futures import ThreadPoolExecutor
 from concurrent.futures import as_completed
@@ -397,7 +399,7 @@ def validate_inputs(args):
     return(args, exes)
 
 
-def search_query(esearch, efilter, qtype, query):
+def search_query(esearch, efilter, qtype, query, typestrain):
     logger = logging.getLogger(__name__)
     # returns list of assembly IDs
     # input is organism search or taxid
@@ -410,6 +412,9 @@ def search_query(esearch, efilter, qtype, query):
     query = query + ' AND latest [PROP] NOT '\
         'partial-genome-representation [PROP]'
 
+    if typestrain:
+        query = query + ' AND "from type" [PROP]'
+
     command = [esearch, '-db', 'assembly', '-query', query]
 
     # logger.debug('Running command:\n' + ' '.join(command))
@@ -534,19 +539,19 @@ def fetch_docsums(efetch, assem_links):
 
     outputs = []
     i = 0
-    nchunk = ceil(len(uid_list)/500)
+    nchunk = ceil(len(uid_list) / 500)
     if nchunk > 0:
         units = 'secs'
-        length = nchunk*10
+        length = nchunk * 10
         if length > 60:
             units = 'mins'
-            length = length/60
+            length = length / 60
             if length > 60:
                 units = 'hours'
-                length = length/60
+                length = length / 60
         logger.info('With {} chunks (500 ids per), this will take around '
                     '{} {}.'.format(nchunk, int(length), units))
-    for chunk in track(chunks(uid_list, 500), 'chunk', nchunk):
+    for chunk in track_wide(chunks(uid_list, 500), 'chunk', nchunk):
         command = [f'{efetch}',
                    '-format', 'docsum',
                    '-mode', 'json',
@@ -560,7 +565,8 @@ def fetch_docsums(efetch, assem_links):
         for j in range(5):
             try:
                 output = subprocess.run(command, stdout=subprocess.PIPE,
-                                        shell=False, text=True, check=True)
+                                        shell=False, text=True, check=True,
+                                        stderr=subprocess.DEVNULL)
             except subprocess.CalledProcessError as e:
                 logger.critical('There was an error running efetch.')
                 logger.critical(f'Check the error: "{e}" and try again.')
@@ -570,7 +576,7 @@ def fetch_docsums(efetch, assem_links):
                 jsondata = json.loads(output.stdout)
             except json.JSONDecodeError:
                 msg = 'No JSON output detected. Retrying. ({})'
-                logger.warning(msg.format(j+1))
+                logger.warning(msg.format(j + 1))
             else:
                 break
         if not jsondata:
@@ -672,7 +678,7 @@ def get_prefix(outformat, name, strain, assem_name):
         logger.debug(f'Seemingly malformed organism name {name} {strain}')
         logger.debug(f'Strain before {strain}')
         try:
-            strain = strain.split(' ',  2)[2]
+            strain = strain.split(' ', 2)[2]
         except IndexError:
             strain = '-'
         logger.debug(f'Strain after {strain}')
@@ -734,7 +740,7 @@ def extract_metadata(force, metadata_append, outformat, typestrain, annotation,
         metadata.append(json_keys + special_keys + ['prefix'])
 
     # for d in decode_stacked_json(docsums):
-    for d in track(docsums, 'docsums', len(docsums)):
+    for d in track_wide(docsums, 'docsums', len(docsums)):
         try:
             json_data = d['result']
         except KeyError:
@@ -1020,6 +1026,7 @@ def download_genomes(o, dl_mapping, threads):
                 )
 
     progress = Progress(
+        SpinnerColumn(),
         TextColumn("[bold blue]{task.fields[filename]}", justify="right"),
         BarColumn(bar_width=None),
         "[progress.percentage]{task.percentage:>3.1f}%",
@@ -1062,7 +1069,7 @@ def main():
     # assem_ids is a list of NCBI assembly IDs
     if args.intype == 'organism':
         assem_links = search_query(exes['esearch'], exes['efilter'],
-                                   args.type, args.query)
+                                   args.type, args.query, args.typestrain)
     elif args.intype == 'assembly_ids':
         assem_links = get_assem_links(exes['epost'], args.infile, args.type)
     elif args.intype == 'nuccore_ids':
